@@ -45,3 +45,11 @@ test_that("Adjusted OR is correct", {
                           bias_parms = c(.94, .85, .64, .25))
     expect_equal(model$adj.measures[2], 1.6346, tolerance = 1e-4, scale = 1)
 })
+
+test_that("bias-factor works", {
+              model <- selection(matrix(c(136, 107, 297, 165),
+                                 nrow = 2, byrow = TRUE),
+                                 bias_parms = 0.43)
+              expect_equal(model$adj.measures[1], 0.7984, tolerance = 1e-4, scale = 1)
+              expect_equal(model$adj.measures[2], 0.7061, tolerance = 1e-4, scale = 1)
+          })
